@@ -414,13 +414,13 @@ build_single_img_dialog (EogCloseConfirmationDialog *dlg)
 	/* Image */
 	image = gtk_image_new_from_icon_name ("dialog-warning-symbolic",
 	                                      GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
 	/* Primary label */
 	primary_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+	gtk_widget_set_halign (primary_label, GTK_ALIGN_START);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	image_name = eog_image_get_caption (img);
@@ -439,7 +439,7 @@ build_single_img_dialog (EogCloseConfirmationDialog *dlg)
 	secondary_label = gtk_label_new (str);
 	g_free (str);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
+	gtk_widget_set_halign (secondary_label, GTK_ALIGN_START);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
@@ -618,7 +618,7 @@ build_multiple_imgs_dialog (EogCloseConfirmationDialog *dlg)
 	/* Image */
 	image = gtk_image_new_from_icon_name ("dialog-warning-symbolic",
 					      GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
@@ -628,7 +628,7 @@ build_multiple_imgs_dialog (EogCloseConfirmationDialog *dlg)
 	primary_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+	gtk_widget_set_halign (primary_label, GTK_ALIGN_START);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	str = g_strdup_printf (
@@ -653,7 +653,7 @@ build_multiple_imgs_dialog (EogCloseConfirmationDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (vbox2), select_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (select_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (select_label), 0.0, 0.5);
+	gtk_widget_set_halign (select_label, GTK_ALIGN_START);
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow, TRUE, TRUE, 0);
@@ -673,7 +673,7 @@ build_multiple_imgs_dialog (EogCloseConfirmationDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (vbox2), secondary_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
+	gtk_widget_set_halign (secondary_label, GTK_ALIGN_START);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (select_label), treeview);
